pub enum Error {
Show 21 variants
Config(ConfigError),
Processing(ProcessingError),
Hrtf(HrtfError),
Position(PositionError),
Room(RoomError),
Audio(AudioError),
Memory(MemoryError),
Gpu(GpuError),
Platform(PlatformError),
Validation(ValidationError),
Io(Error),
Serialization(Error),
Candle(Error),
Generic {
message: String,
code: ErrorCode,
context: Option<Box<ErrorContext>>,
},
LegacyConfig(String),
LegacyProcessing(String),
LegacyHrtf(String),
LegacyPosition(String),
LegacyRoom(String),
LegacyAudio(String),
LegacyValidation(String),
}Expand description
Error types for spatial audio processing
Variants
Config(ConfigError)
Configuration error (structured)
Processing(ProcessingError)
Processing error (structured)
Hrtf(HrtfError)
HRTF error (structured)
Position(PositionError)
Position error (structured)
Room(RoomError)
Room acoustics error (structured)
Audio(AudioError)
Audio error (structured)
Memory(MemoryError)
Memory error (structured)
Gpu(GpuError)
GPU error (structured)
Platform(PlatformError)
Platform error (structured)
Validation(ValidationError)
Validation error (structured)
Io(Error)
I/O error
Serialization(Error)
Serialization error
Candle(Error)
Candle error
Generic
Generic error with context
Fields
context: Option<Box<ErrorContext>>Error context
LegacyConfig(String)
Legacy errors for backward compatibility (will be migrated)
LegacyProcessing(String)
Legacy processing error for backward compatibility
LegacyHrtf(String)
Legacy HRTF error for backward compatibility
LegacyPosition(String)
Legacy position error for backward compatibility
LegacyRoom(String)
Legacy room acoustics error for backward compatibility
LegacyAudio(String)
Legacy audio error for backward compatibility
LegacyValidation(String)
Legacy validation error for backward compatibility
Implementations
Sourceimpl Error
impl Error
Sourcepub fn config(message: &str) -> Self
pub fn config(message: &str) -> Self
Create a generic configuration error from a string message
Sourcepub fn processing(message: &str) -> Self
pub fn processing(message: &str) -> Self
Create a generic processing error from a string message
Sourcepub fn with_context(
message: &str,
code: ErrorCode,
context: ErrorContext,
) -> Self
pub fn with_context( message: &str, code: ErrorCode, context: ErrorContext, ) -> Self
Create error with context
Sourcepub fn is_recoverable(&self) -> bool
pub fn is_recoverable(&self) -> bool
Check if error is recoverable
Sourcepub fn recovery_suggestions(&self) -> Vec<String>
pub fn recovery_suggestions(&self) -> Vec<String>
Get recovery suggestions